AMQP-Storm
-------------
Thread-safe Python RabbitMQ Client Library based on pamqp.

|Version| |CodeClimate| |Travis| |Coverage|

Introduction
-------------
AMQP-Storm is a library designed to be consistent, stable and thread-safe.

- 100% Unit-test Coverage!
- Supports Python 2.6, 2.7 and Python 3+.
- When using a SSL connection, TLSv1 or higher is required.

Documentation
-------------

Additional documentation is available on `ReadTheDocs <https://amqpstorm.readthedocs.org>`_.

Credits
-------------
Special thanks to gmr (Gavin M. Roy) for creating pamqp, and in addition amqpstorm is heavily influenced by his pika and rabbitpy libraries.

.. |Version| image:: https://badge.fury.io/py/amqpstorm.svg?
   :target: http://badge.fury.io/py/amqpstorm

.. |CodeClimate| image:: https://codeclimate.com/github/eandersson/amqpstorm/badges/gpa.svg
   :target: https://codeclimate.com/github/eandersson/amqpstorm

.. |Travis| image:: https://travis-ci.org/eandersson/amqpstorm.svg
   :target: https://travis-ci.org/eandersson/amqpstorm

.. |Coverage| image:: https://codecov.io/gh/eandersson/amqpstorm/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/eandersson/amqpstorm